@@ -1,7 +1,7 @@
 class Merb::AbstractController
   
   class << self
-    attr_accessor :action_argument_list    
+    attr_accessor :action_argument_list
     alias_method :old_inherited, :inherited
 
     # Stores the argument lists for all methods for this class.
@@ -10,8 +10,12 @@ class Merb::AbstractController
     # klass<Class>::
     #   The controller that is being inherited from Merb::AbstractController.
     def inherited(klass)
-      klass.action_argument_list = Hash.new do |h,k| 
-        h[k] = ParseTreeArray.translate(klass, k.to_sym).get_args
+      klass.action_argument_list = Hash.new do |h,k|
+        args = klass.instance_method(k).get_args
+        arguments = args[0]
+        defaults = []
+        arguments.each {|a| defaults << a[0] if a.size == 2} if arguments
+        h[k] = [arguments || [], defaults]
       end
       old_inherited(klass)
     end
@@ -25,10 +29,12 @@ class Merb::AbstractController
   # ==== Raises
   # BadRequest:: The params hash doesn't have a required parameter.
   def _call_action(action)
-    args = self.class.action_argument_list[action].map do |arg, default|
+    arguments, defaults = self.class.action_argument_list[action]
+    
+    args = arguments.map do |arg, default|
       arg = arg
       p = params.key?(arg.to_sym)
-      raise BadRequest unless p || default
+      raise BadRequest unless p || (defaults && defaults.include?(arg))
       p ? params[arg.to_sym] : default
     end
     __send__(action, *args)
