@@ -1,7 +1,23 @@
 require File.dirname(__FILE__) + '/spec_helper'
 
+describe "ActionArgs" do
+  
+  it "should not accidently introduce any methods as controller actions" do
+    Merb::Controller.callable_actions.should be_empty
+  end
+  
+end
+
 describe Merb::AbstractController do
   
+  it "should be able to handle a nested class" do
+    dispatch_to(Awesome::ActionArgs, :index, :foo => "bar").body.should == "bar"
+  end
+  
+  it "should be able to handle no arguments" do
+    dispatch_to(ActionArgs, :nada).body.should == "NADA"
+  end
+  
   it "should be able to accept Action Arguments" do
     dispatch_to(ActionArgs, :index, :foo => "bar").body.should == "bar"
   end
@@ -30,4 +46,12 @@ describe Merb::AbstractController do
     dispatch_to(ActionArgs, :funky_inherited_method, :foo => "bar", :bar => "baz").body.should == "bar baz"
   end
   
+  it "should be able to handle nil defaults" do
+    dispatch_to(ActionArgs, :with_default_nil, :foo => "bar").body.should == "bar "
+  end
+  
+  it "should be able to handle [] defaults" do
+    dispatch_to(ActionArgs, :with_default_array, :foo => "bar").body.should == "bar []"
+  end
+  
 end
\ No newline at end of file
