@@ -8,9 +8,20 @@ module ExtraActions
   end
 end
 
+module Awesome
+  class ActionArgs < Merb::Controller
+    def index(foo)
+      foo.to_s
+    end
+  end
+end
 
 class ActionArgs < Merb::Controller
   include ExtraActions
+
+  def nada
+    "NADA"
+  end
   
   def index(foo)
     foo
@@ -31,5 +42,13 @@ class ActionArgs < Merb::Controller
   define_method :dynamic_define_method do
     "mos def"
   end
+    
+  def with_default_nil(foo, bar = nil)
+    "#{foo} #{bar}"
+  end
+  
+  def with_default_array(foo, bar = [])
+    "#{foo} #{bar.inspect}"
+  end
   
 end
\ No newline at end of file
